/****************************************************************************
* VCGLib                                                            o o     *
* Visual and Computer Graphics Library                            o     o   *
*                                                                _   O  _   *
* Copyright(C) 2004-2016                                           \/)\/    *
* Visual Computing Lab                                            /\/|      *
* ISTI - Italian National Research Council                           |      *
*                                                                    \      *
* All rights reserved.                                                      *
*                                                                           *
* This program is free software; you can redistribute it and/or modify      *
* it under the terms of the GNU General Public License as published by      *
* the Free Software Foundation; either version 2 of the License, or         *
* (at your option) any later version.                                       *
*                                                                           *
* This program is distributed in the hope that it will be useful,           *
* but WITHOUT ANY WARRANTY; without even the implied warranty of            *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
* GNU General Public License (http://www.gnu.org/licenses/gpl.txt)          *
* for more details.                                                         *
*                                                                           *
****************************************************************************/
/*! \file trimesh_base.cpp
\ingroup code_sample

\brief the minimal example of using the lib

This file contain a minimal example of the library, showing how to load a mesh and how to compute per vertex normals on it.

*/

#include<vcg/complex/complex.h>
#include<vcg/complex/algorithms/create/platonic.h>
#include<wrap/io_trimesh/import_off.h>
#include<wrap/io_trimesh/export_ply.h>

class MyVertex; class MyEdge; class MyFace; class MyRealEdge;
struct MyUsedTypes : public vcg::UsedTypes<vcg::Use<MyVertex>   ::AsVertexType,
                                           vcg::Use<MyEdge>     ::AsEdgeType,
                                           vcg::Use<MyFace>     ::AsFaceType>{};

class MyVertex  : public vcg::Vertex< MyUsedTypes, vcg::vertex::Coord3f, vcg::vertex::Normal3f, vcg::vertex::Color4b, vcg::vertex::BitFlags  >{};
class MyFace    : public vcg::Face<   MyUsedTypes, vcg::face::FFAdj, vcg::face::Color4b,  vcg::face::VertexRef, vcg::face::BitFlags > {};
class MyEdge    : public vcg::Edge< MyUsedTypes,vcg::edge::VertexRef, vcg::edge::BitFlags> {};

class MyMesh    : public vcg::tri::TriMesh< std::vector<MyVertex>, std::vector<MyFace> > {};
class MyEdgeMesh    : public vcg::tri::TriMesh< std::vector<MyVertex>,  std::vector<MyEdge>, std::vector<MyFace> > {};

using namespace vcg;


int main( int argc, char **argv )
{
//  if(argc<2)
//  {
//    printf("Usage trimesh_base <meshfilename.off>\n");
//    return -1;
//  }
  /*!
    */
  MyMesh m,addM;
  
  for(int i=0;i<36;++i)
  {
      Matrix44f transl, rotat, rotat2, transf, scaling;
      scaling.SetScale(1,1,3);
      rotat2.SetRotateDeg(i*5,Point3f(0,1,0));
      rotat.SetRotateDeg(i*10,Point3f(0,0,1));
      transl.SetTranslate(10,0,0);
      
      transf = rotat*transl*rotat2*scaling;
      tri::Hexahedron(m);
      tri::UpdatePosition<MyMesh>::Matrix(m,transf);  
      tri::Append<MyMesh,MyMesh>::Mesh(addM,m);
  } 
  tri::io::ExporterPLY<MyMesh>::Save(addM,"cubes.ply");
  
  
  return 0;
}
